<?php

namespace Drupal\locale_delete\Form;

use Drupal\Core\Database\Connection;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a form for deleting a locale.
 */
class LocaleDeleteForm extends ConfirmFormBase {

  /**
   * Locale id.
   */
  protected $lid;

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * Constructs a new LocaleDeleteForm.
   *
   * @param $lid
   *   The locale id.
   */
  public function __construct($lid, Connection $connection) {
    $this->lid = $lid;
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $lid = NULL) {
    return new static(
      $lid,
      $container->get('database')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'locale_delete_delete_confirm';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    $translation = $this->connection->query('SELECT source FROM {locales_source} WHERE [lid] = :lid', [':lid' => $this->lid])->fetchField();

    return $this->t('Are you sure you want to delete the locale "%locale"?', [
      '%locale' => $translation,
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('locale.translate_page');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $lid = NULL) {
    $this->lid = $lid;
    $form = parent::buildForm($form, $form_state);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $translation = $this->connection->query('SELECT source FROM {locales_source} WHERE [lid] = :lid', [':lid' => $this->lid])->fetchField();

    $this->connection->delete('locales_source')
      ->condition('lid', $this->lid)
      ->execute();

    $this->connection->delete('locales_target')
      ->condition('lid', $this->lid)
      ->execute();

    $this->logger('locale_delete')->notice('@type: deleted %translation.', ['%translation' => $translation]);

    $this->messenger()
      ->addStatus($this->t('Deleted %translation.', [
        '%translation' => $translation,
      ]));

    $form_state->setRedirect('locale.translate_page');
  }
}
